yawf
====

.. image:: https://secure.travis-ci.org/freevoid/yawf.png?branch=master
   :target: http://travis-ci.org/freevoid/yawf

For documentation (autogenerated for a moment), see http://yawf.readthedocs.org/
